@@ -1,12 +1,12 @@
 ;;; triples.el --- A flexible triple-based database for use in apps  -*- lexical-binding: t; -*-
 
-;; Copyright (c) 2022, 2023  Free Software Foundation, Inc.
+;; Copyright (c) 2022-2025  Free Software Foundation, Inc.
 
 ;; Author: Andrew Hyatt <ahyatt@gmail.com>
 ;; Homepage: https://github.com/ahyatt/triples
 ;; Package-Requires: ((seq "2.0") (emacs "28.1"))
 ;; Keywords: triples, kg, data, sqlite
-;; Version: 0.5.1
+;; Version: 0.6.0
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
 ;; published by the Free Software Foundation; either version 2 of the
@@ -205,6 +205,7 @@ to be stringified."
       ;; what it would be turned into by the pcase above.
       ((pred null) "()")
       ((pred integerp) val)
+      ((pred floatp) val)
       (_ (format "%S" val)))))
 
 (defun triples-standardize-result (result)
@@ -328,9 +329,9 @@ If LIMIT is a positive integer, limit the results to that number."
                (sqlite-select
                 db
                 (concat "SELECT * FROM triples WHERE predicate = ? AND  "
-                        (if (numberp val)
-                            "CAST(object AS INTEGER) "
-                          "object COLLATE NOCASE ")
+                        (cond ((integerp val) "CAST(object AS INTEGER) ")
+                              ((floatp val) "CAST(object AS REAL) ")
+                              (t "object COLLATE NOCASE "))
                         (symbol-name op) " ?"
                         (when properties " AND properties = ?")
                         (when (and limit (> limit 0)) (format " LIMIT %d" limit)))
